@@ -184,7 +184,7 @@ setMethodS3("extractRawGenomicSignals", "AromaUnitSignalBinaryFile", function(th
   verbose && exit(verbose);
 
   verbose && enter(verbose, "Extracting data");
-  y <- extractMatrix(this, units=units, drop=TRUE, verbose=less(verbose,5));
+  y <- extractMatrix(this, units=units, ..., drop=TRUE, verbose=less(verbose,5));
   verbose && str(verbose, y);
   res <- newInstance(clazz, y, x=pos, chromosome=chromosome);
   res <- setName(res, name);
@@ -214,6 +214,30 @@ setMethodS3("isAverageFile", "AromaUnitSignalBinaryFile", function(this, ...) {
 })
 
 
+setMethodS3("getNumberOfFilesAveraged", "AromaUnitSignalBinaryFile", function(this, units=NULL, ...) {
+  nbrOfUnits <- nbrOfUnits(this);
+
+  # Arguments 'units':
+  if (!is.null(units)) {
+    units <- Arguments$getIndices(units, max=nbrOfUnits);
+    nbrOfUnits <- length(units);
+  }
+
+  if (!isAverageFile(this)) {
+    throw("Cannot retrieve the number of arrays used when averaging. The file is not generated by getAverageFile(), because the filename does not start with '.average-': ", getPathname(this));
+  }
+
+  footer <- readFooter(this);
+  n <- footer$srcDetails$nbrOfFiles;
+  # Validation
+  n <- Arguments$getInteger(n);
+
+  ns <- rep(n, times=nbrOfUnits);
+
+  ns;
+})
+
+
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 # BEGIN Interface API?
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -290,6 +314,13 @@ setMethodS3("getAromaUgpFile", "AromaUnitSignalBinaryFile", function(this, ...,
 
 ############################################################################
 # HISTORY:
+# 2012-07-21
+# o Now extractRawGenomicSignals(...) for AromaUnitSignalBinaryFile()
+#   passes arguments '...' to extractMatrix(...) as well, which makes it
+#   possible to specify column to extract, iff there are more than one.
+# 2012-07-20
+# o Added getNumberOfFilesAveraged() to AromaUnitSignalBinaryFile.
+#   Formely only for AromaUnitTotalCnBinaryFile.
 # 2009-11-19
 # o Added isAverageFile() for AromaUnitSignalBinaryFile.
 # 2009-07-08
