@@ -563,6 +563,7 @@ setMethodS3("interleave", "RasterImage", function(this, what=c("none", "h", "v",
     verbose && printf(verbose, "hOdd=%.2g\n", hOdd);
     verbose && printf(verbose, "hEven=%.2g\n", hEven);
     hRatio <- log(hOdd/hEven);
+    if (is.na(hRatio)) hRatio <- Inf;
     verbose && printf(verbose, "hRatio=%.2g\n", hRatio);
 
     n <- 2*(ncol(z) %/% 2);
@@ -575,22 +576,17 @@ setMethodS3("interleave", "RasterImage", function(this, what=c("none", "h", "v",
     verbose && printf(verbose, "vOdd=%.2g\n", vOdd);
     verbose && printf(verbose, "vEven=%.2g\n", vEven);
     vRatio <- log(vOdd/vEven);
+    if (is.na(vRatio)) vRatio <- Inf;
     verbose && printf(verbose, "vRatio=%.2g\n", vRatio);
 
     what <- "none";
     if (abs(vRatio) > abs(hRatio)) {
       if (abs(vRatio) > 0.25) {
-        if (vRatio > 0)
-          what <- "v"
-        else
-          what <- "v";
+        what <- "v";
       }
     } else {
       if (abs(hRatio) > 0.25) {
-        if (hRatio > 0)
-          what <- "h"
-        else
-          what <- "h";
+        what <- "h";
       }
     }
     verbose && cat(verbose, "what: ", what);
@@ -625,6 +621,11 @@ setMethodS3("interleave", "RasterImage", function(this, what=c("none", "h", "v",
 
 ############################################################################
 # HISTORY:
+# 2012-09-02
+# o BUG FIX: interleave() for Image and RasterImage could generate
+#   error 'Error in if (abs(vRatio) > abs(hRatio)) { : missing value 
+#   where TRUE/FALSE needed' if odd/even cell intensity columns (rows)
+#   contained all NAs.
 # 2012-03-05
 # o BUG FIX: write() for RasterImage would write a transposed image,
 #   and also truncate intensities, because we forgot to rescale [0,65535]
