@@ -1,4 +1,7 @@
 setMethodS3("extractRawCopyNumbers", "RawSequenceReads", function(this, ref=NULL, region=NULL, by, ..., logBase=2, force=FALSE, verbose=FALSE) {
+  # This is a single-chromosome method. Assert that is the case.
+  assertOneChromosome(this);
+
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -50,9 +53,6 @@ setMethodS3("extractRawCopyNumbers", "RawSequenceReads", function(this, ref=NULL
 
   cntList <- lapply(rsrList, FUN=function(rsr) {
     verbose && enter(verbose, "Smoothing");
-    rsr <- clone(rsr);
-    fields <- setdiff(getLocusFields(rsr), "id");
-    setLocusFields(rsr, fields);
     print(verbose, rsr);
     key <- list(method="binnedSums", class=class(rsr)[1], 
          dataChecksum=digest(as.data.frame(rsr)), by=by, region=region);
