@@ -18,7 +18,9 @@
 #     arguments \code{name} and \code{tags}.}
 #   \item{private}{If @FALSE, files and directories starting 
 #     with a periods are ignored.}
-#   \item{...}{Arguments passed to @see "affxparser::findFiles".}
+#   \item{escapes}{A @character @vector specify symbols to be escaped
+#     in argument \code{pattern}.}
+#   \item{...}{Arguments passed to @see "R.utils::findFiles".}
 #   \item{firstOnly}{If @TRUE, only the first matching pathname is returned.}
 #   \item{paths}{A @character @vector of paths to search.
 #     If @NULL, default paths are used.}
@@ -35,9 +37,7 @@
 #
 # @keyword internal
 #*/###########################################################################
-setMethodS3("findAnnotationData", "default", function(name=NULL, tags=NULL, set, pattern=NULL, private=FALSE, ..., firstOnly=TRUE, paths=NULL, verbose=FALSE) {
-  # Needs affxparser::findFiles()
-
+setMethodS3("findAnnotationData", "default", function(name=NULL, tags=NULL, set, pattern=NULL, private=FALSE, escapes=c("+"), ..., firstOnly=TRUE, paths=NULL, verbose=FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Local functions
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -94,7 +94,7 @@ setMethodS3("findAnnotationData", "default", function(name=NULL, tags=NULL, set,
       verbose && enter(verbose, sprintf("Path #%d of %d", kk, length(paths)));
 
       verbose && cat(verbose, "Path: ", path);
-      pathnamesKK <- affxparser::findFiles(..., paths=path);
+      pathnamesKK <- findFiles(..., paths=path);
       verbose && print(verbose, pathnamesKK);
 
       if (length(pathnamesKK) == 0) {
@@ -143,6 +143,9 @@ setMethodS3("findAnnotationData", "default", function(name=NULL, tags=NULL, set,
     throw("Argument 'tags' must be NULL if argument 'name' is: ", tags);
   }
 
+  # Argument 'escapes':
+  escapes <- Arguments$getCharacters(escapes);
+
   # Argument 'set':
   set <- Arguments$getCharacter(set, length=c(1,1));
 
@@ -165,6 +168,15 @@ setMethodS3("findAnnotationData", "default", function(name=NULL, tags=NULL, set,
     }
   }
 
+  # Escape pattern?
+  if (length(escapes) > 0) {
+    escapes <- unlist(strsplit(escapes, split="", fixed=TRUE), use.names=FALSE);
+    escapes <- unique(escapes);
+    escapePattern <- paste(escapes, collapse="");
+    escapePattern <- sprintf("([%s])", escapePattern);
+    pattern <- gsub(escapePattern, "[\\1]", pattern);
+  }
+
   verbose && enter(verbose, "Searching for annotation data file(s)");
 
   verbose && cat(verbose, "Name: ", name);
@@ -345,6 +357,14 @@ setMethodS3("findAnnotationData", "default", function(name=NULL, tags=NULL, set,
 
 ############################################################################
 # HISTORY:
+# 2012-08-29
+# o ROBUSTNESS: Added argument 'escape' to findAnnotationData(), which
+#   causes such symbols that exist in argument 'pattern' to be 
+#   automatically be escaped.  This was done in order for chip types
+#   such as "Mapping250K_Nsp+Sty" to work by default.
+# 2012-04-16
+# o CLEANUP: findAnnotationData() no longer needs affxparser, because
+#   findFiles() is in R.utils (>= 1.13.1).
 # 2011-03-03
 # o Now findAnnotationData() again guarantees that the returned pathnames
 #   are ordered by the (length of the) fullnames.
